from setuptools import setup

setup(name='civeng',
      version='0.2.1',
      description='civil structural engineering tools',
      url='http://github.com/storborg/funniest',
      author='dutu8ure',
      author_email='dutu8ure@gmail.com',
      license='MIT',
      packages=['civeng'],
      zip_safe=False)
